import { defineComponent } from 'vue';
import * as common from 'file-uploader-component';
export * from 'file-uploader-component';
import { indexTemplateHtml } from './variables';
var fileUploadedEventName = 'file-uploaded';
var beforeFileUploadEventName = 'before-upload';
/**
 * @public
 */
export var FileUploader = defineComponent({
    render: indexTemplateHtml,
    props: {
        accept: String,
        multiple: Boolean,
        locale: Object,
        name: String,
        url: String,
        method: String,
    },
    computed: {
        localeObject: function () {
            return common.getLocale(this.locale);
        }
    },
    data: function () {
        return {
            requests: [],
        };
    },
    methods: {
        getProgressWidth: function (request) {
            return {
                width: request.percent + '%'
            };
        },
        onDrop: function (e) {
            var _this = this;
            common.onDrop(e, this.name, this.url, this.method, function (file) {
                _this.$emit('file-got', file);
            }, function (request) {
                _this.$emit(fileUploadedEventName, request.response);
                common.removeRequest(_this.requests, request);
            }, function (percent) {
                // nothing to do
            }, function (request) {
                _this.requests.push(request);
            }, function (r, f) {
                _this.$emit(beforeFileUploadEventName, r, f);
            });
        },
        onPaste: function (e) {
            var _this = this;
            common.onPaste(e, this.name, this.url, this.method, function (file) {
                _this.$emit('file-got', file);
            }, function (request) {
                _this.$emit(fileUploadedEventName, request.response);
                common.removeRequest(_this.requests, request);
            }, function (percent) {
                // nothing to do
            }, function (request) {
                _this.requests.push(request);
            }, function (r, f) {
                _this.$emit(beforeFileUploadEventName, r, f);
            });
        },
        onFileUploaded: function (e) {
            var _this = this;
            common.onFileUploaded(e, this.name, this.url, this.method, function (file) {
                _this.$emit('file-got', file);
            }, function (request) {
                _this.$emit(fileUploadedEventName, request.response);
                common.removeRequest(_this.requests, request);
            }, function (percent) {
                // nothing to do
            }, function (request) {
                _this.requests.push(request);
            }, function (r, f) {
                _this.$emit(beforeFileUploadEventName, r, f);
            });
        },
    }
});
